import gym
import numpy as np
import matplotlib.pyplot as plt
from stable_baselines3 import A2C
from transformers.hf_api import push_to_hub


# Create the CartPole environment
env = gym.make("CartPole-v1")

# Create the A2C model
model = A2C("MlpPolicy", env, verbose=1)

# Train the model
model.learn(total_timesteps=10000)

# Get environment for rendering
vec_env = model.get_env()

# Plotting the rewards
episode_rewards = []
obs = vec_env.reset()
for _ in range(500):
    action, _state = model.predict(obs, deterministic=True)
    obs, reward, done, info = vec_env.step(action)
    # done = terminated or truncated
    episode_rewards.append(reward)
    if done:
        obs = vec_env.reset()

# Plotting the rewards
plt.plot(np.arange(len(episode_rewards)), episode_rewards)
plt.xlabel('Time Steps')
plt.ylabel('Reward')
plt.title('Reward Across Time Steps')
plt.show()


#save the model
model.save("cartpole_model_a2c_sb3")


push_to_hub(
    repo_id="MohamedKhalil/Hands-on-rl",
    filename="cartpole_model_a2c_sb3",
    commit_message="First push",
)